==> haskell-git-lfs-1.2.5-70-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-git-lfs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 git-lfs
version:              1.2.5
visibility:           public
id:                   git-lfs-1.2.5-GT6YLfTg7k7F4KeZTL1g6A
key:                  git-lfs-1.2.5-GT6YLfTg7k7F4KeZTL1g6A
license:              AGPL-3.0-only
copyright:            2019 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             git-lfs protocol
description:          An implementation of the git-lfs protocol.
category:             Network
abi:                  195f9ca41c2efc1f16fbcb9aca7b4e79
exposed:              True
exposed-modules:      Network.GitLFS
import-dirs:          /usr/lib/ghc-9.6.6/site-local/git-lfs-1.2.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/git-lfs-1.2.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/git-lfs-1.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-git-lfs
hs-libraries:         HSgit-lfs-1.2.5-GT6YLfTg7k7F4KeZTL1g6A
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z
    containers-0.6.7 http-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-git-lfs/html/git-lfs.haddock
haddock-html:         /usr/share/doc/haskell-git-lfs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-git-lfs-1.2.5-71-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-git-lfs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 git-lfs
version:              1.2.5
visibility:           public
id:                   git-lfs-1.2.5-Ghnikn9SGiV2GHArSzbCTO
key:                  git-lfs-1.2.5-Ghnikn9SGiV2GHArSzbCTO
license:              AGPL-3.0-only
copyright:            2019 Joey Hess
maintainer:           Joey Hess <id@joeyh.name>
author:               Joey Hess
stability:            Stable
synopsis:             git-lfs protocol
description:          An implementation of the git-lfs protocol.
category:             Network
abi:                  c4c81052301119ad6033fe55af0e8275
exposed:              True
exposed-modules:      Network.GitLFS
import-dirs:          /usr/lib/ghc-9.6.6/site-local/git-lfs-1.2.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/git-lfs-1.2.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/git-lfs-1.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-git-lfs
hs-libraries:         HSgit-lfs-1.2.5-Ghnikn9SGiV2GHArSzbCTO
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    containers-0.6.7 http-client-0.7.19-9XP2fRtq348Edv4XKGE8tD
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-git-lfs/html/git-lfs.haddock
haddock-html:         /usr/share/doc/haskell-git-lfs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
